@@ -47,21 +47,20 @@ class TasksClient(NamespacedClient):
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Cancel a task. WARNING: The task management API is new and should still be considered
-        a beta feature. The API may change in ways that are not backwards compatible.
-        A task may continue to run for some time after it has been cancelled because
-        it may not be able to safely stop its current activity straight away. It is also
-        possible that Elasticsearch must complete its work on other tasks before it can
-        process the cancellation. The get task information API will continue to list
-        these cancelled tasks until they complete. The cancelled flag in the response
-        indicates that the cancellation command has been processed and the task will
-        stop as soon as possible. To troubleshoot why a cancelled task does not complete
-        promptly, use the get task information API with the `?detailed` parameter to
-        identify the other tasks the system is running. You can also use the node hot
-        threads API to obtain detailed information about the work the system is doing
-        instead of completing the cancelled task.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/tasks.html>`_
+          <p>Cancel a task.</p>
+          <p>WARNING: The task management API is new and should still be considered a beta feature.
+          The API may change in ways that are not backwards compatible.</p>
+          <p>A task may continue to run for some time after it has been cancelled because it may not be able to safely stop its current activity straight away.
+          It is also possible that Elasticsearch must complete its work on other tasks before it can process the cancellation.
+          The get task information API will continue to list these cancelled tasks until they complete.
+          The cancelled flag in the response indicates that the cancellation command has been processed and the task will stop as soon as possible.</p>
+          <p>To troubleshoot why a cancelled task does not complete promptly, use the get task information API with the <code>?detailed</code> parameter to identify the other tasks the system is running.
+          You can also use the node hot threads API to obtain detailed information about the work the system is doing instead of completing the cancelled task.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/tasks.html>`_
 
         :param task_id: The task identifier.
         :param actions: A comma-separated list or wildcard expression of actions that
@@ -120,13 +119,16 @@ class TasksClient(NamespacedClient):
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get task information. Get information about a task currently running in the cluster.
-        WARNING: The task management API is new and should still be considered a beta
-        feature. The API may change in ways that are not backwards compatible. If the
-        task identifier is not found, a 404 response code indicates that there are no
-        resources that match the request.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/tasks.html>`_
+          <p>Get task information.
+          Get information about a task currently running in the cluster.</p>
+          <p>WARNING: The task management API is new and should still be considered a beta feature.
+          The API may change in ways that are not backwards compatible.</p>
+          <p>If the task identifier is not found, a 404 response code indicates that there are no resources that match the request.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/tasks.html>`_
 
         :param task_id: The task identifier.
         :param timeout: The period to wait for a response. If no response is received
@@ -174,7 +176,6 @@ class TasksClient(NamespacedClient):
             t.Union[str, t.Literal["nodes", "none", "parents"]]
         ] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         nodes: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         parent_task_id: t.Optional[str] = None,
         pretty: t.Optional[bool] = None,
@@ -182,29 +183,62 @@ class TasksClient(NamespacedClient):
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get all tasks. Get information about the tasks currently running on one or more
-        nodes in the cluster. WARNING: The task management API is new and should still
-        be considered a beta feature. The API may change in ways that are not backwards
-        compatible. **Identifying running tasks** The `X-Opaque-Id header`, when provided
-        on the HTTP request header, is going to be returned as a header in the response
-        as well as in the headers field for in the task information. This enables you
-        to track certain calls or associate certain tasks with the client that started
-        them. For example: ``` curl -i -H "X-Opaque-Id: 123456" "http://localhost:9200/_tasks?group_by=parents"
-        ``` The API returns the following result: ``` HTTP/1.1 200 OK X-Opaque-Id: 123456
-        content-type: application/json; charset=UTF-8 content-length: 831 { "tasks" :
-        { "u5lcZHqcQhu-rUoFaqDphA:45" : { "node" : "u5lcZHqcQhu-rUoFaqDphA", "id" : 45,
-        "type" : "transport", "action" : "cluster:monitor/tasks/lists", "start_time_in_millis"
-        : 1513823752749, "running_time_in_nanos" : 293139, "cancellable" : false, "headers"
-        : { "X-Opaque-Id" : "123456" }, "children" : [ { "node" : "u5lcZHqcQhu-rUoFaqDphA",
-        "id" : 46, "type" : "direct", "action" : "cluster:monitor/tasks/lists[n]", "start_time_in_millis"
-        : 1513823752750, "running_time_in_nanos" : 92133, "cancellable" : false, "parent_task_id"
-        : "u5lcZHqcQhu-rUoFaqDphA:45", "headers" : { "X-Opaque-Id" : "123456" } } ] }
-        } } ``` In this example, `X-Opaque-Id: 123456` is the ID as a part of the response
-        header. The `X-Opaque-Id` in the task `headers` is the ID for the task that was
-        initiated by the REST request. The `X-Opaque-Id` in the children `headers` is
-        the child task of the task that was initiated by the REST request.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/tasks.html>`_
+          <p>Get all tasks.
+          Get information about the tasks currently running on one or more nodes in the cluster.</p>
+          <p>WARNING: The task management API is new and should still be considered a beta feature.
+          The API may change in ways that are not backwards compatible.</p>
+          <p><strong>Identifying running tasks</strong></p>
+          <p>The <code>X-Opaque-Id header</code>, when provided on the HTTP request header, is going to be returned as a header in the response as well as in the headers field for in the task information.
+          This enables you to track certain calls or associate certain tasks with the client that started them.
+          For example:</p>
+          <pre><code>curl -i -H &quot;X-Opaque-Id: 123456&quot; &quot;http://localhost:9200/_tasks?group_by=parents&quot;
+          </code></pre>
+          <p>The API returns the following result:</p>
+          <pre><code>HTTP/1.1 200 OK
+          X-Opaque-Id: 123456
+          content-type: application/json; charset=UTF-8
+          content-length: 831
+
+          {
+            &quot;tasks&quot; : {
+              &quot;u5lcZHqcQhu-rUoFaqDphA:45&quot; : {
+                &quot;node&quot; : &quot;u5lcZHqcQhu-rUoFaqDphA&quot;,
+                &quot;id&quot; : 45,
+                &quot;type&quot; : &quot;transport&quot;,
+                &quot;action&quot; : &quot;cluster:monitor/tasks/lists&quot;,
+                &quot;start_time_in_millis&quot; : 1513823752749,
+                &quot;running_time_in_nanos&quot; : 293139,
+                &quot;cancellable&quot; : false,
+                &quot;headers&quot; : {
+                  &quot;X-Opaque-Id&quot; : &quot;123456&quot;
+                },
+                &quot;children&quot; : [
+                  {
+                    &quot;node&quot; : &quot;u5lcZHqcQhu-rUoFaqDphA&quot;,
+                    &quot;id&quot; : 46,
+                    &quot;type&quot; : &quot;direct&quot;,
+                    &quot;action&quot; : &quot;cluster:monitor/tasks/lists[n]&quot;,
+                    &quot;start_time_in_millis&quot; : 1513823752750,
+                    &quot;running_time_in_nanos&quot; : 92133,
+                    &quot;cancellable&quot; : false,
+                    &quot;parent_task_id&quot; : &quot;u5lcZHqcQhu-rUoFaqDphA:45&quot;,
+                    &quot;headers&quot; : {
+                      &quot;X-Opaque-Id&quot; : &quot;123456&quot;
+                    }
+                  }
+                ]
+              }
+            }
+           }
+          </code></pre>
+          <p>In this example, <code>X-Opaque-Id: 123456</code> is the ID as a part of the response header.
+          The <code>X-Opaque-Id</code> in the task <code>headers</code> is the ID for the task that was initiated by the REST request.
+          The <code>X-Opaque-Id</code> in the children <code>headers</code> is the child task of the task that was initiated by the REST request.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/tasks.html>`_
 
         :param actions: A comma-separated list or wildcard expression of actions used
             to limit the request. For example, you can use `cluser:*` to retrieve all
@@ -214,9 +248,6 @@ class TasksClient(NamespacedClient):
             other but is more costly to run.
         :param group_by: A key that is used to group tasks in the response. The task
             lists can be grouped either by nodes or by parent tasks.
-        :param master_timeout: The period to wait for a connection to the master node.
-            If no response is received before the timeout expires, the request fails
-            and returns an error.
         :param nodes: A comma-separated list of node IDs or names that is used to limit
             the returned information.
         :param parent_task_id: A parent task identifier that is used to limit returned
@@ -243,8 +274,6 @@ class TasksClient(NamespacedClient):
             __query["group_by"] = group_by
         if human is not None:
             __query["human"] = human
-        if master_timeout is not None:
-            __query["master_timeout"] = master_timeout
         if nodes is not None:
             __query["nodes"] = nodes
         if parent_task_id is not None:
