@@ -20,40 +20,47 @@ import typing as t
 from elastic_transport import ObjectApiResponse
 
 from ._base import NamespacedClient
-from .utils import SKIP_IN_PATH, _quote, _rewrite_parameters
+from .utils import (
+    SKIP_IN_PATH,
+    Stability,
+    _quote,
+    _rewrite_parameters,
+    _stability_warning,
+)
 
 
 class SearchableSnapshotsClient(NamespacedClient):
+
     @_rewrite_parameters()
+    @_stability_warning(Stability.EXPERIMENTAL)
     def cache_stats(
         self,
         *,
-        node_id: t.Optional[
-            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
-        ] = None,
+        node_id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         error_trace: t.Optional[bool] = None,
-        filter_path: t.Optional[
-            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
-        ] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieve node-level cache statistics about searchable snapshots.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/searchable-snapshots-apis.html>`_
+          <p>Get cache statistics.
+          Get statistics about the shared cache for partially mounted indices.</p>
 
-        :param node_id: A comma-separated list of node IDs or names to limit the returned
-            information; use `_local` to return information from the node you're connecting
-            to, leave empty to get information from all nodes
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/searchable-snapshots-api-cache-stats.html>`_
+
+        :param node_id: The names of the nodes in the cluster to target.
         :param master_timeout:
         """
+        __path_parts: t.Dict[str, str]
         if node_id not in SKIP_IN_PATH:
-            __path = f"/_searchable_snapshots/{_quote(node_id)}/cache/stats"
+            __path_parts = {"node_id": _quote(node_id)}
+            __path = f'/_searchable_snapshots/{__path_parts["node_id"]}/cache/stats'
         else:
+            __path_parts = {}
             __path = "/_searchable_snapshots/cache/stats"
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
@@ -68,47 +75,46 @@ class SearchableSnapshotsClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="searchable_snapshots.cache_stats",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
+    @_stability_warning(Stability.EXPERIMENTAL)
     def clear_cache(
         self,
         *,
-        index: t.Optional[t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]] = None,
+        index: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         allow_no_indices: t.Optional[bool] = None,
         error_trace: t.Optional[bool] = None,
         expand_wildcards: t.Optional[
             t.Union[
-                t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str],
-                t.Union[
-                    t.List[
-                        t.Union[
-                            "t.Literal['all', 'closed', 'hidden', 'none', 'open']", str
-                        ]
-                    ],
-                    t.Tuple[
-                        t.Union[
-                            "t.Literal['all', 'closed', 'hidden', 'none', 'open']", str
-                        ],
-                        ...,
-                    ],
+                t.Sequence[
+                    t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]]
                 ],
+                t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]],
             ]
         ] = None,
-        filter_path: t.Optional[
-            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
-        ] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         ignore_unavailable: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Clear the cache of searchable snapshots.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/searchable-snapshots-apis.html>`_
+          <p>Clear the cache.
+          Clear indices and data streams from the shared cache for partially mounted indices.</p>
 
-        :param index: A comma-separated list of index names
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/searchable-snapshots-api-clear-cache.html>`_
+
+        :param index: A comma-separated list of data streams, indices, and aliases to
+            clear from the cache. It supports wildcards (`*`).
         :param allow_no_indices: Whether to ignore if a wildcard indices expression resolves
             into no concrete indices. (This includes `_all` string or when no indices
             have been specified)
@@ -117,9 +123,12 @@ class SearchableSnapshotsClient(NamespacedClient):
         :param ignore_unavailable: Whether specified concrete indices should be ignored
             when unavailable (missing or closed)
         """
+        __path_parts: t.Dict[str, str]
         if index not in SKIP_IN_PATH:
-            __path = f"/{_quote(index)}/_searchable_snapshots/cache/clear"
+            __path_parts = {"index": _quote(index)}
+            __path = f'/{__path_parts["index"]}/_searchable_snapshots/cache/clear'
         else:
+            __path_parts = {}
             __path = "/_searchable_snapshots/cache/clear"
         __query: t.Dict[str, t.Any] = {}
         if allow_no_indices is not None:
@@ -138,115 +147,149 @@ class SearchableSnapshotsClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "POST", __path, params=__query, headers=__headers
+            "POST",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="searchable_snapshots.clear_cache",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters(
-        body_fields=True,
+        body_fields=(
+            "index",
+            "ignore_index_settings",
+            "index_settings",
+            "renamed_index",
+        ),
     )
     def mount(
         self,
         *,
         repository: str,
         snapshot: str,
-        index: str,
+        index: t.Optional[str] = None,
         error_trace: t.Optional[bool] = None,
-        filter_path: t.Optional[
-            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
-        ] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        ignore_index_settings: t.Optional[
-            t.Union[t.List[str], t.Tuple[str, ...]]
-        ] = None,
+        ignore_index_settings: t.Optional[t.Sequence[str]] = None,
         index_settings: t.Optional[t.Mapping[str, t.Any]] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         renamed_index: t.Optional[str] = None,
         storage: t.Optional[str] = None,
         wait_for_completion: t.Optional[bool] = None,
+        body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Mount a snapshot as a searchable index.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/searchable-snapshots-api-mount-snapshot.html>`_
+          <p>Mount a snapshot.
+          Mount a snapshot as a searchable snapshot index.
+          Do not use this API for snapshots managed by index lifecycle management (ILM).
+          Manually mounting ILM-managed snapshots can interfere with ILM processes.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/searchable-snapshots-api-mount-snapshot.html>`_
 
         :param repository: The name of the repository containing the snapshot of the
-            index to mount
-        :param snapshot: The name of the snapshot of the index to mount
-        :param index:
-        :param ignore_index_settings:
-        :param index_settings:
-        :param master_timeout: Explicit operation timeout for connection to master node
-        :param renamed_index:
-        :param storage: Selects the kind of local storage used to accelerate searches.
-            Experimental, and defaults to `full_copy`
-        :param wait_for_completion: Should this request wait until the operation has
-            completed before returning
+            index to mount.
+        :param snapshot: The name of the snapshot of the index to mount.
+        :param index: The name of the index contained in the snapshot whose data is to
+            be mounted. If no `renamed_index` is specified, this name will also be used
+            to create the new index.
+        :param ignore_index_settings: The names of settings that should be removed from
+            the index when it is mounted.
+        :param index_settings: The settings that should be added to the index when it
+            is mounted.
+        :param master_timeout: The period to wait for the master node. If the master
+            node is not available before the timeout expires, the request fails and returns
+            an error. To indicate that the request should never timeout, set it to `-1`.
+        :param renamed_index: The name of the index that will be created.
+        :param storage: The mount option for the searchable snapshot index.
+        :param wait_for_completion: If true, the request blocks until the operation is
+            complete.
         """
         if repository in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'repository'")
         if snapshot in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'snapshot'")
-        if index is None:
+        if index is None and body is None:
             raise ValueError("Empty value passed for parameter 'index'")
-        __path = f"/_snapshot/{_quote(repository)}/{_quote(snapshot)}/_mount"
-        __body: t.Dict[str, t.Any] = {}
+        __path_parts: t.Dict[str, str] = {
+            "repository": _quote(repository),
+            "snapshot": _quote(snapshot),
+        }
+        __path = (
+            f'/_snapshot/{__path_parts["repository"]}/{__path_parts["snapshot"]}/_mount'
+        )
         __query: t.Dict[str, t.Any] = {}
-        if index is not None:
-            __body["index"] = index
+        __body: t.Dict[str, t.Any] = body if body is not None else {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
         if filter_path is not None:
             __query["filter_path"] = filter_path
         if human is not None:
             __query["human"] = human
-        if ignore_index_settings is not None:
-            __body["ignore_index_settings"] = ignore_index_settings
-        if index_settings is not None:
-            __body["index_settings"] = index_settings
         if master_timeout is not None:
             __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
-        if renamed_index is not None:
-            __body["renamed_index"] = renamed_index
         if storage is not None:
             __query["storage"] = storage
         if wait_for_completion is not None:
             __query["wait_for_completion"] = wait_for_completion
+        if not __body:
+            if index is not None:
+                __body["index"] = index
+            if ignore_index_settings is not None:
+                __body["ignore_index_settings"] = ignore_index_settings
+            if index_settings is not None:
+                __body["index_settings"] = index_settings
+            if renamed_index is not None:
+                __body["renamed_index"] = renamed_index
         __headers = {"accept": "application/json", "content-type": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "POST", __path, params=__query, headers=__headers, body=__body
+            "POST",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="searchable_snapshots.mount",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
     def stats(
         self,
         *,
-        index: t.Optional[t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]] = None,
+        index: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         error_trace: t.Optional[bool] = None,
-        filter_path: t.Optional[
-            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
-        ] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         level: t.Optional[
-            t.Union["t.Literal['cluster', 'indices', 'shards']", str]
+            t.Union[str, t.Literal["cluster", "indices", "shards"]]
         ] = None,
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieve shard-level statistics about searchable snapshots.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/searchable-snapshots-apis.html>`_
+          <p>Get searchable snapshot statistics.</p>
 
-        :param index: A comma-separated list of index names
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.19/searchable-snapshots-api-stats.html>`_
+
+        :param index: A comma-separated list of data streams and indices to retrieve
+            statistics for.
         :param level: Return stats aggregated at cluster, index or shard level
         """
+        __path_parts: t.Dict[str, str]
         if index not in SKIP_IN_PATH:
-            __path = f"/{_quote(index)}/_searchable_snapshots/stats"
+            __path_parts = {"index": _quote(index)}
+            __path = f'/{__path_parts["index"]}/_searchable_snapshots/stats'
         else:
+            __path_parts = {}
             __path = "/_searchable_snapshots/stats"
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
@@ -261,5 +304,10 @@ class SearchableSnapshotsClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="searchable_snapshots.stats",
+            path_parts=__path_parts,
         )
