@@ -17,8 +17,10 @@
 
 import base64
 import inspect
+import urllib.parse
 import warnings
 from datetime import date, datetime
+from enum import Enum, auto
 from functools import wraps
 from typing import (
     TYPE_CHECKING,
@@ -30,6 +32,7 @@ from typing import (
     List,
     Mapping,
     Optional,
+    Sequence,
     Set,
     Tuple,
     Type,
@@ -50,12 +53,12 @@ from elastic_transport.client_utils import (
     client_meta_version,
     create_user_agent,
     parse_cloud_id,
-    percent_encode,
     url_to_node_config,
 )
 
 from ..._version import __versionstr__
 from ...compat import to_bytes, to_str, warn_stacklevel
+from ...exceptions import GeneralAvailabilityWarning
 
 if TYPE_CHECKING:
     from ._base import NamespacedClient
@@ -69,7 +72,18 @@ CLIENT_META_SERVICE = ("es", client_meta_version(__versionstr__))
 # Default User-Agent used by the client
 USER_AGENT = create_user_agent("elasticsearch-py", __versionstr__)
 
-_TYPE_HOSTS = Union[str, List[Union[str, Mapping[str, Union[str, int]], NodeConfig]]]
+
+class Stability(Enum):
+    STABLE = auto()
+    BETA = auto()
+    EXPERIMENTAL = auto()
+
+
+_TYPE_HOSTS = Union[
+    str, Sequence[Union[str, Mapping[str, Union[str, int]], NodeConfig]]
+]
+
+_TYPE_BODY = Union[bytes, str, Dict[str, Any]]
 
 _TYPE_ASYNC_SNIFF_CALLBACK = Callable[
     [AsyncTransport, SniffOptions], Awaitable[List[NodeConfig]]
@@ -120,7 +134,6 @@ def client_node_configs(
 
     def apply_node_options(node_config: NodeConfig) -> NodeConfig:
         """Needs special handling of headers since .replace() wipes out existing headers"""
-        nonlocal node_options
         headers = node_config.headers.copy()  # type: ignore[attr-defined]
 
         headers_to_add = node_options.pop("headers", ())
@@ -139,7 +152,7 @@ def hosts_to_node_configs(hosts: _TYPE_HOSTS) -> List[NodeConfig]:
     """Transforms the many formats of 'hosts' into NodeConfigs"""
 
     # To make the logic here simpler we reroute everything to be List[X]
-    if not isinstance(hosts, (tuple, list)):
+    if isinstance(hosts, str):
         return hosts_to_node_configs([hosts])
 
     node_configs: List[NodeConfig] = []
@@ -218,7 +231,7 @@ def host_mapping_to_node_config(host: Mapping[str, Union[str, int]]) -> NodeConf
         )
         options["path_prefix"] = options.pop("url_prefix")
 
-    return NodeConfig(**options)  # type: ignore
+    return NodeConfig(**options)  # type: ignore[arg-type]
 
 
 def cloud_id_to_node_configs(cloud_id: str) -> List[NodeConfig]:
@@ -274,7 +287,7 @@ def _escape(value: Any) -> str:
 
 
 def _quote(value: Any) -> str:
-    return percent_encode(_escape(value), ",*")
+    return urllib.parse.quote(_escape(value), ",*")
 
 
 def _quote_query(query: Mapping[str, Any]) -> str:
@@ -286,22 +299,49 @@ def _merge_kwargs_no_duplicates(kwargs: Dict[str, Any], values: Dict[str, Any])
         if key in kwargs:
             raise ValueError(
                 f"Received multiple values for '{key}', specify parameters "
-                "directly instead of using 'body' or 'params'"
+                "directly instead of using 'params'"
             )
         kwargs[key] = val
 
 
+def _merge_body_fields_no_duplicates(
+    body: _TYPE_BODY, kwargs: Dict[str, Any], body_fields: Tuple[str, ...]
+) -> bool:
+    mixed_body_and_params = False
+    for key in list(kwargs.keys()):
+        if key in body_fields:
+            if isinstance(body, (str, bytes)):
+                raise ValueError(
+                    "Couldn't merge 'body' with other parameters as it wasn't a mapping."
+                )
+
+            if key in body:
+                raise ValueError(
+                    f"Received multiple values for '{key}', specify parameters "
+                    "using either body or parameters, not both."
+                )
+
+            warnings.warn(
+                f"Received '{key}' via a specific parameter in the presence of a "
+                "'body' parameter, which is deprecated and will be removed in a future "
+                "version. Instead, use only 'body' or only specific parameters.",
+                category=DeprecationWarning,
+                stacklevel=warn_stacklevel(),
+            )
+            body[key] = kwargs.pop(key)
+            mixed_body_and_params = True
+    return mixed_body_and_params
+
+
 def _rewrite_parameters(
     body_name: Optional[str] = None,
-    body_fields: bool = False,
+    body_fields: Optional[Tuple[str, ...]] = None,
     parameter_aliases: Optional[Dict[str, str]] = None,
     ignore_deprecated_options: Optional[Set[str]] = None,
 ) -> Callable[[F], F]:
     def wrapper(api: F) -> F:
         @wraps(api)
         def wrapped(*args: Any, **kwargs: Any) -> Any:
-            nonlocal api, body_name, body_fields
-
             # Let's give a nicer error message when users pass positional arguments.
             if len(args) >= 2:
                 raise TypeError(
@@ -369,7 +409,8 @@ def _rewrite_parameters(
             if "body" in kwargs and (
                 not ignore_deprecated_options or "body" not in ignore_deprecated_options
             ):
-                body = kwargs.pop("body")
+                body: Optional[_TYPE_BODY] = kwargs.pop("body")
+                mixed_body_and_params = False
                 if body is not None:
                     if body_name:
                         if body_name in kwargs:
@@ -379,30 +420,27 @@ def _rewrite_parameters(
                                 f"'{body_name}' parameter. See https://github.com/elastic/elasticsearch-py/"
                                 "issues/1698 for more information"
                             )
-
-                        warnings.warn(
-                            "The 'body' parameter is deprecated and will be removed "
-                            f"in a future version. Instead use the '{body_name}' parameter. "
-                            "See https://github.com/elastic/elasticsearch-py/issues/1698 "
-                            "for more information",
-                            category=DeprecationWarning,
-                            stacklevel=warn_stacklevel(),
-                        )
                         kwargs[body_name] = body
-
-                    elif body_fields:
-                        if not hasattr(body, "items"):
-                            raise ValueError(
-                                "Couldn't merge 'body' with other parameters as it wasn't a mapping. "
-                                "Instead of using 'body' use individual API parameters"
-                            )
-                        warnings.warn(
-                            "The 'body' parameter is deprecated and will be removed "
-                            "in a future version. Instead use individual parameters.",
-                            category=DeprecationWarning,
-                            stacklevel=warn_stacklevel(),
+                    elif body_fields is not None:
+                        mixed_body_and_params = _merge_body_fields_no_duplicates(
+                            body, kwargs, body_fields
                         )
-                        _merge_kwargs_no_duplicates(kwargs, body)
+                        kwargs["body"] = body
+
+                    if parameter_aliases and not isinstance(body, (str, bytes)):
+                        for alias, rename_to in parameter_aliases.items():
+                            if rename_to in body:
+                                body[alias] = body.pop(rename_to)
+                                # If body and params are mixed, the alias may come from a param,
+                                # in which case the warning below will not make sense.
+                                if not mixed_body_and_params:
+                                    warnings.warn(
+                                        f"Using '{rename_to}' alias in 'body' is deprecated and will be removed "
+                                        f"in a future version of elasticsearch-py. Use '{alias}' directly instead. "
+                                        "See https://github.com/elastic/elasticsearch-py/issues/1698 for more information",
+                                        category=DeprecationWarning,
+                                        stacklevel=2,
+                                    )
 
             if parameter_aliases:
                 for alias, rename_to in parameter_aliases.items():
@@ -418,6 +456,37 @@ def _rewrite_parameters(
     return wrapper
 
 
+def _stability_warning(
+    stability: Stability,
+    version: Optional[str] = None,
+    message: Optional[str] = None,
+) -> Callable[[F], F]:
+    def wrapper(api: F) -> F:
+        @wraps(api)
+        def wrapped(*args: Any, **kwargs: Any) -> Any:
+            if stability == Stability.BETA:
+                warnings.warn(
+                    "This API is in beta and is subject to change. "
+                    "The design and code is less mature than official GA features and is being provided as-is with no warranties. "
+                    "Beta features are not subject to the support SLA of official GA features.",
+                    category=GeneralAvailabilityWarning,
+                    stacklevel=warn_stacklevel(),
+                )
+            elif stability == Stability.EXPERIMENTAL:
+                warnings.warn(
+                    "This API is in technical preview and may be changed or removed in a future release. "
+                    "Elastic will work to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.",
+                    category=GeneralAvailabilityWarning,
+                    stacklevel=warn_stacklevel(),
+                )
+
+            return api(*args, **kwargs)
+
+        return wrapped  # type: ignore[return-value]
+
+    return wrapper
+
+
 def is_requests_http_auth(http_auth: Any) -> bool:
     """Detect if an http_auth value is a custom Requests auth object"""
     try:
